@@ -27,8 +27,6 @@
 
 #if defined(USE_SDL)
 #include <surface_sdl.h>
-#elif defined(USE_NOVIDEO)
-#include <surface_none.h>
 #else
 #error "A video backend must be specified."
 #endif
